@@ -5,7 +5,7 @@ use warnings;
 
 use parent 'Perl::Critic::Policy::Community::LoopOnHash';
 
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 sub default_themes { 'freenode' }
 
@@ -21,8 +21,7 @@ Legacy C<freenode> theme policy alias.
 
 =head1 POLICY MOVED
 
-This policy has been moved to the C<community> theme and renamed to
-L<Perl::Critic::Policy::Community::LoopOnHash>.
+This policy has been moved to L<Perl::Critic::Community>.
 
 =head1 AFFILIATION
 
